==> mobile_pos-0.8.12.tar.gz: lib/src/styles/ravenpay_app_colors.dart <==
import 'package:flutter/widgets.dart';

class AppColors {
  static Color ravenPayGreen = const Color(0xff014345);
  static Color ravenPayGrey = const Color(0xff676767);
  static Color lightGreen = const Color(0xffF8FFFC);
  static Color lightGrey = const Color(0xffF8FFFC);
  static Color ravenPayGrey2 = const Color(0xffCCCCCC);
  static Color darkGrey = const Color(0xff333333);
  static Color lightGrey2 = const Color(0xffD9D9D9);
  static Color ravenPayDark = const Color(0xff020202);
  static Color ravenDarkGreen = const Color(0xff014345);
  static Color ravenOrageColor = const Color(0xffEA872D);
  static Color lightOragen = const Color(0xffFFF6ED);
  static Color lightOrange2 = const Color(0xffEEBB87);
  static Color ravenPayGrey3 = const Color(0xff676767);
  static Color ravenPayGrey4 = const Color(0xffB3B3B3);
  static Color ravenLightGrey = const Color(0xffD9D9D9);
  static Color ravenLightGrey4 = const Color(0xffF7F8F7);
  static Color ravenGreyLight = const Color(0xff9BE5C9);
  static Color ravenGreyLight1 = const Color(0xffACACAC);
  static Color ravenGrey4 = const Color(0xffE3E3E3);
  static Color ravenDark = const Color(0xff1B1B1B);
  static Color ravenDarkGrey = const Color(0xffF9F9F9);
  static Color ravenSuccessColor = const Color(0xff1ACE37);
  static Color ravenRed = const Color(0xffFF0F00);
  static Color bankBoxSecondaryColor = const Color(0xFF000000);
  static Color greyColor2 = const Color(0xFFE5E6E6);
  static Color borderGrey = const Color(0xffEEEEEE);
  static const lightTextColor = Color(0xff8B8B8B);
  static Color bankBoxGreen = const Color(0xff0B8376);
}

==> mobile_pos-1.1.1.tar.gz: lib/src/styles/ravenpay_app_colors.dart <==
import 'package:flutter/widgets.dart';

class AppColors {
  static Color ravenPayGreen = const Color(0xff014345);
  static Color ravenPayGrey = const Color(0xff676767);
  static Color lightGreen = const Color(0xffF8FFFC);
  static Color lightGrey = const Color(0xffF8FFFC);
  static Color ravenPayGrey2 = const Color(0xffCCCCCC);
  static Color darkGrey = const Color(0xff333333);
  static Color lightGrey2 = const Color(0xffD9D9D9);
  static Color ravenPayDark = const Color(0xff020202);
  static Color ravenDarkGreen = const Color(0xff014345);
  static Color ravenOrangeColor = const Color(0xffEA872D);
  static Color lightOrange = const Color(0xffFFF6ED);
  static Color lightOrange2 = const Color(0xffEEBB87);
  static Color ravenPayGrey3 = const Color(0xff676767);
  static Color ravenPayGrey4 = const Color(0xffB3B3B3);
  static Color ravenLightGrey = const Color(0xffD9D9D9);
  static Color ravenLightGrey4 = const Color(0xffF7F8F7);
  static Color ravenGreyLight = const Color(0xff9BE5C9);
  static Color ravenGreyLight1 = const Color(0xffACACAC);
  static Color ravenGrey4 = const Color(0xffE3E3E3);
  static Color ravenDark = const Color(0xff1B1B1B);
  static Color ravenDarkGrey = const Color(0xffF9F9F9);
  static Color ravenSuccessColor = const Color(0xff1ACE37);
  static Color ravenRed = const Color(0xffFF0F00);
  static Color bankBoxSecondaryColor = const Color(0xFF000000);
  static Color greyColor2 = const Color(0xFFE5E6E6);
  static Color borderGrey = const Color(0xffEEEEEE);
  static const lightTextColor = Color(0xff8B8B8B);
  static Color bankBoxGreen = const Color(0xff0B8376);
  static Color lightGrey3 = const Color(0xffF7F7F7);
  static Color darkModeFG = const Color(0xff212121);
  static Color lightBlue = const Color(0xffE9F5FF);
  static Color lightPurple = const Color(0xffF0EEFF);

  //Borders
  static Color darkModeBorder = const Color(0xFF333333).withOpacity(.5);
  static Color lightModeBorder = const Color(0xFFF2f2f2).withOpacity(.8);
}
